@@ -1,5 +1,6 @@
       SUBROUTINE AUTARMF(N,LAGH01,CYY1,NEWL1,IQI1,B1,IPI1,A1,
-     *	       NEWN,IQ,B2,IP,A2,STD,CXX2,G,SAIC,AICM,KQ,KP,TMP,
+cx     *	       NEWN,IQ,B2,IP,A2,STD,CXX2,G,SAIC,AICM,KQ,KP,TMP,IER,
+     *	       NEWN,IQ,B2,IP,A2,STD,CXX2,G,SAIC,AICM,KQ,KP,
      *           LMAX,MMAX,NMAX)
 C
       INCLUDE 'timsac_f.h'
@@ -96,8 +97,8 @@ cxx      DIMENSION A1(IPI1(1)),B1(IQI1(1))
       DIMENSION A2(MMAX,NMAX),B2(MMAX,NMAX)
       DIMENSION SMAIC2(NMAX),CXX2(NMAX)
 C
-      INTEGER*1  TMP(1)
-      CHARACTER  CNAME*80
+cx      INTEGER*1  TMP(1)
+cx      CHARACTER  CNAME*80
 C
 C     INPUT / OUTPUT DATA FILE OPEN
 cc	CHARACTER(100) DFNAM
@@ -106,27 +107,31 @@ cc	DFNAM='autarm.out'
 cc	CALL FLOPN3(DFNAM,NFL)
 cc	IF (NFL.EQ.0) GO TO 999
 c
-      LU=3
-      DO 7 I = 1,80
-    7 CNAME(I:I) = ' '
-      I = 1
-      IFG = 1
-      DO WHILE( (IFG.EQ.1) .AND. (I.LE.80) )
-	   IF ( TMP(I).NE.ICHAR(' ') ) THEN
-            CNAME(I:I) = CHAR(TMP(I))
-            I = I+1
-         ELSE
-            IFG = 0
-         END IF
-      END DO
-      IF ( I.GT.1 ) THEN
-         IFG = 1
-         OPEN (LU,FILE=CNAME,IOSTAT=IVAR)
-         IF (IVAR .NE. 0) THEN
-            WRITE(*,*) ' ***  autarm temp FILE OPEN ERROR :',CNAME,IVAR
-            IFG=0
-         END IF
-      END IF
+cx      IER=0
+cx      LU=3
+cx      DO 7 I = 1,80
+cx    7 CNAME(I:I) = ' '
+cx      I = 1
+cx      IFG = 1
+cx      DO WHILE( (IFG.EQ.1) .AND. (I.LE.80) )
+cx	   IF ( TMP(I).NE.ICHAR(' ') ) THEN
+cx            CNAME(I:I) = CHAR(TMP(I))
+cx            I = I+1
+cx         ELSE
+cx            IFG = 0
+cx         END IF
+cx      END DO
+cx      IF ( I.GT.1 ) THEN
+cx         IFG = 1
+cx         OPEN (LU,FILE=CNAME,IOSTAT=IVAR)
+cx         IF (IVAR .NE. 0) THEN
+cxcx            WRITE(*,*) ' ***  autarm temp FILE OPEN ERROR :',CNAME,IVAR
+cx            IER=IVAR
+cx            IFG=0
+cx         END IF
+cx      ELSE
+cx         IFG = 0
+cx      END IF
 C
       CST0=0.0D-00
       CST1=1.0D-00
@@ -195,7 +200,7 @@ cc 4206 READ(5,1) IQI(I),IPI(I)
       ISWRO=0
 C     INITIAL PRINT OUT
 cc	WRITE (6,11111)
-      IF (IFG.NE.0) WRITE(LU,11111)
+cx      IF (IFG.NE.0) WRITE(LU,11111)
 cc	WRITE(6,1600)
 cc	WRITE(6,1601)
 cc	WRITE(6,1610) N,LAGH,IQ,IP
@@ -213,20 +218,20 @@ cc	WRITE(6,1621)
 cc	DO 1631 I=1,IP
 cc 1631 WRITE(6,1611) I,A(I)
 cc 4216 CONTINUE
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,3112) ISWRO
- 3112	 FORMAT(/' ISWRO=',I5)
-	 IF (JQ.GT.0) THEN
-	      WRITE(LU,1622)
-	    DO 1632 I=1,JQ
- 1632	    WRITE(LU,1611) I,B(I)
-	 END IF
- 4215	 IF (JP.GT.0) THEN
-	    WRITE(LU,1621)
-	    DO 1631 I=1,JP
- 1631	    WRITE(LU,1611) I,A(I)
-	 END IF
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,3112) ISWRO
+cx 3112	 FORMAT(/' ISWRO=',I5)
+cx	 IF (JQ.GT.0) THEN
+cx	      WRITE(LU,1622)
+cx	    DO 1632 I=1,JQ
+cx 1632	    WRITE(LU,1611) I,B(I)
+cx	 END IF
+cx 4215	 IF (JP.GT.0) THEN
+cx	    WRITE(LU,1621)
+cx	    DO 1631 I=1,JP
+cx 1631	    WRITE(LU,1611) I,A(I)
+cx	 END IF
+cx      END IF
 cc	DO 100 I=1,IP
       DO 100 I=1,JP
   100 X(I)=A(I)
@@ -245,7 +250,8 @@ cc	CALL SC0GRH(X,CYY,G,CN,CXX0,IP,IQ)
 C     INVERSE OF HESSIAN COMPUTATION
 C     COMMON SUBROUTINE CALL
 cc	CALL MATINV(HESDET,IPQ)
-      CALL MATINV(IPQ,VD,MMAX,0,LU)
+cxx      CALL MATINV(IPQ,VD,MMAX,0,LU)
+      CALL MATINV(IPQ,VD,MMAX)
 C     CORRECTION TERM C(X)=V*G(X) COMPUTATION
       DO 900 I=1,IPQ
       SUM=CST0
@@ -291,32 +297,33 @@ cc  930 B(I)=X(II)
   925 CONTINUE
       IF(ISFIN.EQ.0) GO TO 940
 cc	WRITE(6,926)
-      IF (IFG.NE.0) WRITE(LU,926)
+cx      IF (IFG.NE.0) WRITE(LU,926)
   926 FORMAT(/1H ,'HESSIAN RESET')
       GO TO 4210
   940 CONTINUE
 cc	WRITE(6,1008) CXX0
-      IF (IFG.NE.0) WRITE(LU,1008) CXX0
+cx      IF (IFG.NE.0) WRITE(LU,1008) CXX0
 C     HESSIAN COMPUTATION
       ISWRO=1
 cc	CALL SC0GRH(X,CYY,G,CN,CXX0,IP,IQ)
       CALL SC0GRH(X,CYY,G(1,NEWN),CN,CXX0,JP,JQ,VD,MMAX,LMAX,ICST,
      *		  IFG,LU)
 cc	WRITE(6,1008) CXX0
-      IF (IFG.NE.0) WRITE(LU,1008) CXX0
+cx      IF (IFG.NE.0) WRITE(LU,1008) CXX0
 C     INVERSE OF HESSIAN COMPUTATION
 C     COMMON SUBROUTINE CALL
 cc	CALL MATINV(HESD2,IPQ)
-      CALL MATINV(IPQ,VD,MMAX,0,LU)
+cxx      CALL MATINV(IPQ,VD,MMAX,0,LU)
+      CALL MATINV(IPQ,VD,MMAX)
 C     INVERSE OF HESSIAN PRINT OUT
 cc	WRITE(6,3000)
 cc	DO 3100 I=1,IPQ
 cc 3100 WRITE(6,3110) I,(VD(I,J),J=1,IPQ)
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,3000)
-	 DO 3100 I=1,IPQ
- 3100	 WRITE(LU,3110) I,(VD(I,J),J=1,IPQ)
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,3000)
+cx	 DO 3100 I=1,IPQ
+cx 3100	 WRITE(LU,3110) I,(VD(I,J),J=1,IPQ)
+cx      END IF
 C     PARAMETER VARIANCE MATRIX COMPUTATION
       AN=N
       CONST1=CXX0/AN
@@ -326,11 +333,11 @@ C     PARAMETER VARIANCE MATRIX COMPUTATION
 cc	WRITE(6,6100)
 cc	DO 6200 I=1,IPQ
 cc 6200 WRITE(6,3110) I,(VD(I,J),J=1,IPQ)
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,6100)
-	 DO 6200 I=1,IPQ
- 6200	 WRITE(LU,3110) I,(VD(I,J),J=1,IPQ)
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,6100)
+cx	 DO 6200 I=1,IPQ
+cx 6200	 WRITE(LU,3110) I,(VD(I,J),J=1,IPQ)
+cx      END IF
       DO 6400 I=1,IPQ
       IF(VD(I,I).LT.CST0) VD(I,I)=CST0
 cc 6400 STD(I)=DSQRT(VD(I,I))
@@ -340,10 +347,10 @@ cc	WRITE(6,8000)
       SAN=CST2/DSQRT(AN)
 cc	WRITE(6,7999) SAN
 cc	WRITE(6,7998) (CN(I),I=2,51)
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,8000) SAN
-	 WRITE(LU,7998) (CN(I),I=2,MMAX+1)
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,8000) SAN
+cx	 WRITE(LU,7998) (CN(I),I=2,MMAX+1)
+cx      END IF
 cc	DO 800 I=1,IP
 cc  800 A(I)=X(I)
 cc	IF(IQ.LE.0) GO TO 820
@@ -359,7 +366,7 @@ cc  810 B(I)=X(II)
   820 CONTINUE
 cc	WRITE(6,7910)
 cc	WRITE(6,1014) NEWN
-      IF (IFG.NE.0) WRITE(LU,1014) NEWN
+cx      IF (IFG.NE.0) WRITE(LU,1014) NEWN
  1014 FORMAT(//1H ,'CASE NO.',I5)
 cc	IF(IQ.LE.0) GO TO 4290
 cc	IF(IQ(NEWN).LE.0) GO TO 4290
@@ -376,7 +383,7 @@ C     INVERSE OF AR(B) COMPUTATION
 cc	CALL INVERS(B,IQ,A,0,CC,IB,IG)
       CALL INVERS(B,JQ,A,0,CC,IB,IG,IFG,LU)
 cc	WRITE(6,4289) IB
-      IF (IFG.NE.0) WRITE(LU,4289) IB
+cx      IF (IFG.NE.0) WRITE(LU,4289) IB
 cc 4290 IF(IP.LE.0) GO TO 4291
 cc	WRITE(6,865)
 cc	DO 866 I=1,IP
@@ -525,7 +532,7 @@ cc	IDE=IABS(IQI(I)-IQ)+IABS(IPI(I)-IP)
       IF(IDO.EQ.4) GO TO 2116
       IF(IDO.EQ.5) GO TO 2117
 cc	WRITE(6,2153)
-      IF (IFG.NE.0) WRITE(LU,2153)
+cx      IF (IFG.NE.0) WRITE(LU,2153)
  2153 FORMAT(//1H ,'BORDER CHECK COMPLETED')
       GO TO 2120
  2154 NEWL=NEWL+1
@@ -551,7 +558,7 @@ cc	STOP
       AICM=SMAIC2(NEWN)
 	KQ=IQO(NEWN)
       KP=IPO(NEWN)
-      IF (IFG.NE.0) CLOSE(LU)
+cx      IF (IFG.NE.0) CLOSE(LU)
       RETURN
     1 FORMAT(16I5)
     2 FORMAT(4D20.10)
@@ -641,7 +648,7 @@ cc   25 CALL INVERS(A,IP,B,0,AI,IA,IG)
       CAI1=CAI1*DSR2
  1941 A(I)=A(I)*CAI1
 cc	WRITE(6,1940)
-      IF (IFG.NE.0) WRITE(LU,1940)
+cx      IF (IFG.NE.0) WRITE(LU,1940)
  1940 FORMAT(1H ,'NON-INVERTIBLE MA PART')
       IF(ISIK.NE.0) GO TO 1899
       IG=0
@@ -730,12 +737,12 @@ cc	WRITE(6,2502)
 cc 2500 WRITE(6,3000) LXX,LXY,LZX,LZY,LUX,LUU,LUZ,LUY,LUYU,LZYZ,IA,IAIB,
 cc     AIA2B
 cc 2501 WRITE(6,3000) MXX,MXY,MZX,MZY,MUX,MUU,MUZ,MUY,MUYU,MZYZ
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,2502)
- 2500	 WRITE(LU,3000) LXX,LXY,LZX,LZY,LUX,LUU,LUZ,LUY,LUYU,LZYZ,
-     *	 IA,IAIB,IA2B
- 2501	 WRITE(LU,3000) MXX,MXY,MZX,MZY,MUX,MUU,MUZ,MUY,MUYU,MZYZ
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,2502)
+cx 2500	 WRITE(LU,3000) LXX,LXY,LZX,LZY,LUX,LUU,LUZ,LUY,LUYU,LZYZ,
+cx     *	 IA,IAIB,IA2B
+cx 2501	 WRITE(LU,3000) MXX,MXY,MZX,MZY,MUX,MUU,MUZ,MUY,MUYU,MZYZ
+cx      END IF
 C     CXX0 COMPUTATION
 C     CYX=CYY*AIB'
 cc	CALL SCONVL(CYY,AIB,CYX,IAIB,LYX,MYX)
@@ -1190,14 +1197,14 @@ C     OUTPUT X(I) (I=1,IX)
    24 IF(GAM2.LE.GAMMAX) GO TO 26
       IG=1
 cc	WRITE(6,60)
-      IF (IFG.NE.0) WRITE(LU,60)
+cx      IF (IFG.NE.0) WRITE(LU,60)
       GO TO 1000
    26 IH=0
    10 CONTINUE
       IF(IH.GE.LH) GO TO 1000
       IG=1
 cc	WRITE(6,59)
-      IF (IFG.NE.0) WRITE(LU,59)
+cx      IF (IFG.NE.0) WRITE(LU,59)
       GO TO 1000
   999 IX=0
  1000 RETURN
