@@ -120,6 +120,11 @@ cc	DO 3112 J=1,7
       DO 3112 J=1,IR
       G(I,J)=CST0
  3112 CONTINUE
+c---
+      DO 3113 J=1,MJ1
+      F(I,J)=CST0
+ 3113 CONTINUE
+c---
  3111 CONTINUE
 C     INITIAL CONDITION INPUT
 cc	READ(5,1) IR
