@@ -1,5 +1,6 @@
       SUBROUTINE MARKOVF(N,LAGH3,ID,CYY0,K,NH,JAW,AW1,B1,ICONT,
-     *IDD,IR,IJ,IK,IPQ,G,A1,A,B,VD,IQM,BM,AU,ZZ,C0,AICD,TMP,
+cx     *IDD,IR,IJ,IK,IPQ,G,A1,A,B,VD,IQM,BM,AU,ZZ,C0,AICD,TMP,IER,
+     *IDD,IR,IJ,IK,IPQ,G,A1,A,B,VD,IQM,BM,AU,ZZ,C0,AICD,
      *MJ3,MJ4,MJ6,MJ7)
 C
       INCLUDE 'timsac_f.h'
@@ -110,8 +111,8 @@ C
       DIMENSION O(50,ID,K),Q(50,K,ID),X1(50,K,K),X2(50,ID,ID)
       DIMENSION CXY1(100,ID,ID),CXX1(51,ID,ID),CXV1(51,ID,K)
 C
-      INTEGER*1  TMP(1)
-      CHARACTER  CNAME*80
+cx      INTEGER*1  TMP(1)
+cx      CHARACTER  CNAME*80
 C
 C     INPUT / OUTPUT DATA FILE OPEN
 cc	CHARACTER(100) DFNAM
@@ -120,27 +121,29 @@ cc	DFNAM='markov.out'
 cc	CALL FLOPN3(DFNAM,NFL)
 cc	IF (NFL.EQ.0) GO TO 999
 c
-      LU=3
-      DO 10 I = 1,80
-   10 CNAME(I:I) = ' '
-      I = 1
-      IFG = 1
-      DO WHILE( (IFG.EQ.1) .AND. (I.LE.80) )
-	   IF ( TMP(I).NE.ICHAR(' ') ) THEN
-            CNAME(I:I) = CHAR(TMP(I))
-            I = I+1
-         ELSE
-            IFG = 0
-         END IF
-      END DO
-      IF ( I.GT.1 ) THEN
-         IFG = 1
-         OPEN (LU,FILE=CNAME,IOSTAT=IVAR)
-         IF (IVAR .NE. 0) THEN
-            WRITE(*,*) ' ***  markov temp FILE OPEN ERROR :',CNAME,IVAR
-            IFG=0
-         END IF
-      END IF
+cx      IER=0
+cx      LU=3
+cx      DO 10 I = 1,80
+cx   10 CNAME(I:I) = ' '
+cx      I = 1
+cx      IFG = 1
+cx      DO WHILE( (IFG.EQ.1) .AND. (I.LE.80) )
+cx	   IF ( TMP(I).NE.ICHAR(' ') ) THEN
+cx            CNAME(I:I) = CHAR(TMP(I))
+cx            I = I+1
+cx         ELSE
+cx            IFG = 0
+cx         END IF
+cx      END DO
+cx      IF ( I.GT.1 ) THEN
+cx         IFG = 1
+cx         OPEN (LU,FILE=CNAME,IOSTAT=IVAR)
+cx         IF (IVAR .NE. 0) THEN
+cxcx            WRITE(*,*) ' ***  markov temp FILE OPEN ERROR :',CNAME,IVAR
+cx            IER=IVAR
+cx            IFG=0
+cx         END IF
+cx      END IF
 C
 C     ABSOLUTE DIMENSIONS USED FOR SUBROUTINE CALL
 cc	MJ1=10
@@ -255,7 +258,7 @@ C     IPQ=TOTAL NUMBER OF FREE PARAMETERS
       AIPQ=IPQ
       IDP1=ID+1
 cc	WRITE(6,411) ISWRO
-      IF (IFG.NE.0) WRITE(LU,411) ISWRO
+cx      IF (IFG.NE.0) WRITE(LU,411) ISWRO
   411 FORMAT(/1H ,'ISWRO=',I5)
       DO 500 I=1,IAW
   500 X(I)=AW(I)
@@ -269,8 +272,9 @@ C     OF LOG(DET.CXX0(0)) COMPUTATION
       KSWR=0
       IG=0
 cc	CALL C0GR(X,C0,G,M,L,K,ID,IAW,IPQ,MJ1,MJ2,IG)
-      CALL C0GR(CYY1,MJ3,B,AW,IAW,IDD,IR,IJ,IK,X,C0,G,M,L,K,ID,IPQ,
-     *          MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+      CALL C0GR(CYY1,MJ3,B,AW,IAW,NH,IDD,IR,IJ,IK,X,C0,G,M,L,K,ID,IPQ,
+cx     *                MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+     *                MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1)
       DO 1500 I=1,IAW
  1500 X(I)=AW(I)
       JJ=IAW
@@ -284,14 +288,14 @@ cc 1360 WRITE(6,351) I,AW(I)
 cc	WRITE(6,53)
 cc	DO 2181 I=1,K
 cc 2181 WRITE(6,2200) I,(B(I,J),J=1,ID)
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,340)
-	 DO 1360 I=1,IAW
- 1360	 WRITE(LU,351) I,AW(I)
-	 WRITE(LU,53)
-	 DO 2181 I=1,K
- 2181	 WRITE(LU,2200) I,(B(I,J),J=1,ID)
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,340)
+cx	 DO 1360 I=1,IAW
+cx 1360	 WRITE(LU,351) I,AW(I)
+cx	 WRITE(LU,53)
+cx	 DO 2181 I=1,K
+cx 2181	 WRITE(LU,2200) I,(B(I,J),J=1,ID)
+cx      END IF
 C
 C     HESSIAN COMPUTATION
 cc	CALL SUBHES(M,L,K,ID,IAW,MJ1,MJ2)
@@ -301,24 +305,25 @@ cc	CALL SUBHES(M,L,K,ID,IAW,MJ1,MJ2)
 cc	WRITE(6,2000)
 cc	DO 2100 I=1,IPQ
 cc 2100 WRITE(6,2200) I,(VD(I,J),J=1,IPQ)
-      IF (IFG.NE.0) THEN
-	   WRITE(LU,2000)
-	 DO 2100 I=1,IPQ
- 2100	 WRITE(LU,2200) I,(VD(I,J),J=1,IPQ)
-	 WRITE(LU,'(/)')
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	   WRITE(LU,2000)
+cx	 DO 2100 I=1,IPQ
+cx 2100	 WRITE(LU,2200) I,(VD(I,J),J=1,IPQ)
+cx	 WRITE(LU,'(/)')
+cx      END IF
 C     (INVERSE OF HESSIAN) COMPUTATION
 cc 2651 CALL MATINV(IPQ)
- 2651 CALL MATINV(IPQ,VD,MJ4,IFG,LU)
+cxx 2651 CALL MATINV(IPQ,VD,MJ4,IFG,LU)
+ 2651 CALL MATINV(IPQ,VD,MJ4)
       IF(ISWRO.GT.0) GO TO 2650
 cc	WRITE(6,2500)
 cc	DO 2600 I=1,IPQ
 cc 2600 WRITE(6,2200) I,(VD(I,J),J=1,IPQ)
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,2500)
-	 DO 2600 I=1,IPQ
- 2600	 WRITE(LU,2200) I,(VD(I,J),J=1,IPQ)
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,2500)
+cx	 DO 2600 I=1,IPQ
+cx 2600	 WRITE(LU,2200) I,(VD(I,J),J=1,IPQ)
+cx      END IF
 C
 C     CORRECTION R(X)=V*G(X) COMPUTATION
  2650 DO 100 I=1,IPQ
@@ -334,8 +339,9 @@ C     ORIGINAL PARAMETER VALUES
  2656 OB(I,J)=B(I,J)
 C     DAVIDON'S PROCEDURE
 cc	CALL SUBDAV(X,C0,G,R,N,K,ID,IAW,IPQ,MJ1,MJ2,ISWRO)
-      CALL SUBDAV(CYY1,MJ3,B,AW,IAW,IDD,IR,IJ,IK,VD,X,C0,G,R,N,K,ID,
-     *      IPQ,AICD,MJ1,MJ4,ISWRO,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+      CALL SUBDAV(CYY1,MJ3,B,AW,IAW,NH,IDD,IR,IJ,IK,VD,X,C0,G,R,N,K,
+cx     * ID,IPQ,AICD,MJ1,MJ4,ISWRO,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+     * ID,IPQ,AICD,MJ1,MJ4,ISWRO,O,Q,X1,X2,CXY1,CXX1,CXV1)
       ISFIN=0
       IF(ISWRO.GE.20) GO TO 599
       IF (ISWRO.EQ.0) GO TO 599
@@ -406,7 +412,7 @@ C
 cc	CALL FLCLS3(NFL)
   999 CONTINUE
 cc	STOP
-      IF (IFG.NE.0) CLOSE(LU)
+cx      IF (IFG.NE.0) CLOSE(LU)
       RETURN
     1 FORMAT(16I5)
     2 FORMAT(4D20.10)
@@ -449,8 +455,9 @@ cc 2200 FORMAT(/1H ,I5,10D12.5,/(1H ,5X,10D12.5))
       END
 C
 cc	SUBROUTINE C0GR(X,C0,GR,M,L,K,ID,IAW,IPQ,MJ1,MJ2,IG)
-      SUBROUTINE C0GR(CYY1,MJ3,B,AW,IAW,IDD,IR,IJ,IK,X,C0,GR,M,L,K,ID,
-     *                IPQ,MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+      SUBROUTINE C0GR(CYY1,MJ3,B,AW,IAW,NH,IDD,IR,IJ,IK,X,C0,GR,M,L,K,
+cx     *                   ID,IPQ,MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+     *                   ID,IPQ,MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1)
 C     THIS SUBROUTINE COMPUTES THE INNOVATION MATRIX CXX(0) AND
 C     THE GRADIENT OF LOG(DET CXX(0))
       IMPLICIT REAL*8(A-H,O-Z)
@@ -461,7 +468,7 @@ cc	DIMENSION CYY1(160,5,5),B(10,5),AW(50)
 cc	DIMENSION IDD(10),IR(10),IJ(5),IK(5)
 cc	DIMENSION X(100),C0(10,10),GR(100)
       DIMENSION CYY1(MJ3,ID,ID),B(K,ID),AW(IAW)
-      DIMENSION IDD(K),IR(K),IJ(ID),IK(ID)
+      DIMENSION NH(K),IDD(K),IR(K),IJ(ID),IK(ID)
       DIMENSION X(MJ4),C0(ID,ID),GR(MJ4)
       DIMENSION O(50,ID,K),Q(50,K,ID),X1(50,K,K),X2(50,ID,ID)
       DIMENSION CXY1(100,ID,ID),CXX1(51,ID,ID),CXV1(51,ID,K)
@@ -479,8 +486,10 @@ C     IMPULSE RESPONSE COMPUTATION
       IG2=IG
 cc	CALL NSUBX1(K,ID,M,MJ1,MJ2,IG1)
 cc	CALL NSUBX2(K,ID,KK,MJ1,MJ2,IG2)
-      CALL NSUBX1(B,AW,IAW,IDD,IR,K,ID,M,IG1,X1,IFG,LU)
-      CALL NSUBX2(B,AW,IAW,IDD,IR,K,ID,KK,IG2,Q,X2,IFG,LU)
+cx      CALL NSUBX1(B,AW,IAW,NH,IDD,IR,IJ,K,ID,M,IG1,X1,IFG,LU)
+cx      CALL NSUBX2(B,AW,IAW,IDD,IR,K,ID,KK,IG2,Q,X2,IFG,LU)
+      CALL NSUBX1(B,AW,IAW,NH,IDD,IR,IJ,K,ID,M,IG1,X1)
+      CALL NSUBX2(B,AW,IAW,IDD,IR,K,ID,KK,IG2,Q,X2)
       IG=IG1+IG2
       IF(KSWR.EQ.0) GO TO 620
       IF(IG.NE.0) GO TO 1000
@@ -499,13 +508,15 @@ cc	CALL NSUBO(C0,K,ID,M,MJ1,MJ2)
       CALL NSUBO(C0,K,ID,M,O,X1)
 C     GRADIENT GA AND GB COMPUTATION
 cc	CALL GRAD(GR,M,K,ID,IAW,IPQ,MJ1,MJ2)
-      CALL GRAD(IJ,IK,GR,M,K,ID,IAW,IPQ,MJ4,O,CXX1,CXV1,IFG,LU)
+cx      CALL GRAD(IJ,IK,GR,M,K,ID,IAW,IPQ,MJ4,O,CXX1,CXV1,IFG,LU)
+      CALL GRAD(IJ,IK,GR,M,K,ID,IAW,IPQ,MJ4,O,CXX1,CXV1)
  1000 KSWR=1
       RETURN
       END
 C
 cc	SUBROUTINE NSUBX1(K,ID,M,MJ1,MJ2,IG1)
-      SUBROUTINE NSUBX1(B,AW,IAW,IDD,IR,K,ID,M,IG1,X1,IFG,LU)
+cx      SUBROUTINE NSUBX1(B,AW,IAW,NH,IDD,IR,IJ,K,ID,M,IG1,X1,IFG,LU)
+      SUBROUTINE NSUBX1(B,AW,IAW,NH,IDD,IR,IJ,K,ID,M,IG1,X1)
 C     THIS SUBROUTINE COMPUTES THE IMPULSE RESPONSE OF
 C     (INVERSE OF (C*(INVERSE OF PHAI)*B))*C*
 C     (INVERSE OF PHAI). PHAI = INVERSE OF (I-A*EXP(-I*2*PI*F)).
@@ -523,7 +534,7 @@ cc	COMMON /COM82/AW
       COMMON /COM99/ISWR
 cc	DIMENSION IDD(10),IR(10)
 cc	DIMENSION AW(50),B(10,5)
-      DIMENSION IDD(K),IR(K)
+      DIMENSION NH(K),IDD(K),IR(K),IJ(ID)
       DIMENSION AW(IAW),B(K,ID)
 cc      DIMENSION X1(50,10,10)
 cc	DIMENSION V(10,10),AV(10,10)
@@ -627,11 +638,11 @@ C
   770 M=49
 cc	WRITE(6,2000) M,XMAX
 cc	WRITE( 6,2001 )
-      IF (IFG.NE.0) THEN
-	 WRITE( LU,2000) M,XMAX
-	 WRITE( LU,2001 )
- 2001	 FORMAT( 1H ,'WARNING : INCOMPLETE CONVERGENCE' )
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE( LU,2000) M,XMAX
+cx	 WRITE( LU,2001 )
+cx 2001	 FORMAT( 1H ,'WARNING : INCOMPLETE CONVERGENCE' )
+cx      END IF
       IG1=1
       IF(ISWR.GE.1) GO TO 771
       IG1=0
@@ -639,23 +650,25 @@ C     RESCALING FOR A FEASIBLE INITIAL
       IF(ITINP.GE.50) GO TO 771
       ITINP=ITINP+1
 cc	CALL RESCAL(K,ID)
-      CALL RESCAL(B,AW,IAW,NH,IDD,IR,IJ,IK,K,ID,IFG,LU)
+cx      CALL RESCAL(B,AW,IAW,NH,IDD,IR,IJ,IK,K,ID,IFG,LU)
+      CALL RESCAL(B,AW,IAW,NH,IDD,IR,IJ,IK,K,ID)
 cc	WRITE(6,2330) ITINP
-      IF (IFG.NE.0) WRITE(LU,2330) ITINP
+cx      IF (IFG.NE.0) WRITE(LU,2330) ITINP
  2330 FORMAT(//1H ,'ITINP=',I5)
       GO TO 199
   771 ISWR=ISWR+1
       RETURN
   760 M=NS-LH
 cc	WRITE(6,2000) M,XMAX
-      IF (IFG.NE.0) WRITE(LU,2000) M,XMAX
+cx      IF (IFG.NE.0) WRITE(LU,2000) M,XMAX
  2000 FORMAT(1H ,'M=',I5,5X,'XMAX1=',D12.5)
       ISWR=ISWR+1
       RETURN
       END
 C
 cc	SUBROUTINE NSUBX2(K,ID,KK,MJ1,MJ2,IG2)
-      SUBROUTINE NSUBX2(B,AW,IAW,IDD,IR,K,ID,KK,IG2,Q,X2,IFG,LU)
+cx      SUBROUTINE NSUBX2(B,AW,IAW,IDD,IR,K,ID,KK,IG2,Q,X2,IFG,LU)
+      SUBROUTINE NSUBX2(B,AW,IAW,IDD,IR,K,ID,KK,IG2,Q,X2)
 C     THIS SUBROUTINE COMPUTES X2(NS,I,J) AND U(NS),
 C     NS=0,1,2,...,L(=KK).
 C
@@ -748,16 +761,16 @@ C
   770 KK=49
 cc	WRITE(6,2200) KK,XMAX
 cc	WRITE( 6,2300 )
-      IF (IFG.NE.0) THEN
-	 WRITE( LU,2200) KK,XMAX
-	 WRITE( LU,2300 )
- 2300	 FORMAT( 1H ,'WARNING : X2 INCOMPLETE CONVERGENCE' )
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE( LU,2200) KK,XMAX
+cx	 WRITE( LU,2300 )
+cx 2300	 FORMAT( 1H ,'WARNING : X2 INCOMPLETE CONVERGENCE' )
+cx      END IF
       IG2=1
       RETURN
   760 KK=NS-LH
 cc	WRITE(6,2200) KK,XMAX
-      IF (IFG.NE.0) WRITE(LU,2200) KK,XMAX
+cx      IF (IFG.NE.0) WRITE(LU,2200) KK,XMAX
  2200 FORMAT(1H ,'KK=',I5,5X,'XMAX2=',D12.5)
       RETURN
       END
@@ -817,7 +830,8 @@ cc	DIMENSION XX(MJ6,MJ7)
       END
 C
 cc	SUBROUTINE GRAD(GR,M,K,ID,IAW,IPQ,MJ1,MJ2)
-      SUBROUTINE GRAD(IJ,IK,GR,M,K,ID,IAW,IPQ,MJ4,O,CXX1,CXV1,IFG,LU)
+cx      SUBROUTINE GRAD(IJ,IK,GR,M,K,ID,IAW,IPQ,MJ4,O,CXX1,CXV1,IFG,LU)
+      SUBROUTINE GRAD(IJ,IK,GR,M,K,ID,IAW,IPQ,MJ4,O,CXX1,CXV1)
 C     THIS SUBROUTINE COMPUTES GRADIENT (GA AND GB).
 C     GA=-2.0*(O(0)'*CXV1(1)+O(1)'*CXV1(2)+O(2)'*CXV1(3)+...+O(NSL)'*CXV
 C     1(1+NSL)).
@@ -895,8 +909,8 @@ C     K>ID
   510 GR(JJ)=-CST2*ZB(I,J)
 cc	WRITE(6,1400)
 cc	CALL SUBVCP(GR,IPQ)
-      IF (IFG.NE.0) WRITE(LU,1400)
-      IF (IFG.NE.0) CALL SUBVCP(GR,IPQ,LU)
+cx      IF (IFG.NE.0) WRITE(LU,1400)
+cx      IF (IFG.NE.0) CALL SUBVCP(GR,IPQ,LU)
       RETURN
  1400 FORMAT(/1H ,'GRADIENT')
       END
@@ -1552,8 +1566,9 @@ cc	CALL MATADL(Z,ZZ,ID,ID,MJ2,MJ2)
       END
 C
 cc	SUBROUTINE SUBDAV(X,C0,G,R,N,K,ID,IAW,IPQ,MJ1,MJ2,ISWRO)
-      SUBROUTINE SUBDAV(CYY1,MJ3,B,AW,IAW,IDD,IR,IJ,IK,VD,X,C0,G,R,N,K,
-     *    ID,IPQ,AICD,MJ1,MJ4,ISWRO,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+      SUBROUTINE SUBDAV(CYY1,MJ3,B,AW,IAW,NH,IDD,IR,IJ,IK,VD,X,C0,G,R,
+cx     *  N,K,ID,IPQ,AICD,MJ1,MJ4,ISWRO,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+     *  N,K,ID,IPQ,AICD,MJ1,MJ4,ISWRO,O,Q,X1,X2,CXY1,CXX1,CXV1)
 C     DAVIDON'S (MINIMIZATION) PROCEDURE
       IMPLICIT REAL*8(A-H,O-Z)
 cc	COMMON /COM50/VD
@@ -1570,7 +1585,8 @@ cc	DIMENSION AW(50),IDD(10),IR(10)
       DIMENSION VD(MJ4,MJ4)
       DIMENSION X(MJ4),C0(ID,ID),G(MJ4),R(MJ4),C0D(ID,ID)
       DIMENSION SX(MJ4),SC0(ID,ID),SC0D(ID,ID),SG(MJ4),SR(MJ4)
-      DIMENSION AW(IAW),IDD(K),IR(K)
+cc      DIMENSION AW(IAW),IDD(K),IR(K)
+      DIMENSION AW(IAW),NH(K),IDD(K),IR(K)
       DIMENSION O(50,ID,K),Q(50,K,ID),X1(50,K,K),X2(50,ID,ID)
       DIMENSION CXY1(100,ID,ID),CXX1(51,ID,ID),CXV1(51,ID,K)
 C
@@ -1597,14 +1613,15 @@ C     CONSTANT
       PHAID=CST1
 C
 cc  150 WRITE(6,160) ITN
-  150 IF (IFG.NE.0) WRITE(LU,160) ITN
+cx  150 IF (IFG.NE.0) WRITE(LU,160) ITN
   160 FORMAT(//1H ,'ITN=',I5)
+  150 CONTINUE
 C
 C     RO=G'*R COMPUTATION
       ITNS=0
    40 CALL INNERP(G,R,RO,IPQ)
 cc	WRITE(6,2210) RO
-      IF (IFG.NE.0) WRITE(LU,2210) RO
+cx      IF (IFG.NE.0) WRITE(LU,2210) RO
       IF(IPHAI.EQ.0) GO TO 101
 C     DETERMINANT OF CXX(0) COMPUTATION
       DO 100 I=1,ID
@@ -1636,19 +1653,21 @@ C     R=RAM*R
 C
 C     SX=X-R
 cc  140 WRITE(6,600) ITNS,T1,EPHAI1
-  140 IF (IFG.NE.0) WRITE(LU,600) ITNS,T1,EPHAI1
+cx  140 IF (IFG.NE.0) WRITE(LU,600) ITNS,T1,EPHAI1
   600 FORMAT(1H ,'ITNS=',I5,5X,'RO-2.0*PHAI=',D12.5,5X,'EPHAI1=',D12.5)
+  140 CONTINUE
       IG=0
   205 DO 210 I=1,IPQ
   210 SX(I)=X(I)-R(I)
 C
 C     SPHAI, SG COMPUTATION
 cc	CALL C0GR(SX,SC0,SG,M,L,K,ID,IAW,IPQ,MJ1,MJ2,IG)
-      CALL C0GR(CYY1,MJ3,B,AW,IAW,IDD,IR,IJ,IK,SX,SC0,SG,M,L,K,ID,IPQ,
-     *          MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+      CALL C0GR(CYY1,MJ3,B,AW,IAW,NH,IDD,IR,IJ,IK,SX,SC0,SG,M,L,K,ID,
+cx     *        IPQ,MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1,IFG,LU)
+     *        IPQ,MJ4,IG,O,Q,X1,X2,CXY1,CXX1,CXV1)
       IF(IG.EQ.0) GO TO 215
 cc	WRITE(6,211)
-      IF (IFG.NE.0) WRITE(LU,211)
+cx      IF (IFG.NE.0) WRITE(LU,211)
   211 FORMAT(1H ,'HESSIAN MODIFIED FOR FEASIBILITY')
       DO 213 I=1,IPQ
       R(I)=CST05*R(I)
@@ -1675,7 +1694,7 @@ C     SRO=(SG)'*(SR)
       CALL INNERP(SG,SR,SRO,IPQ)
       SROD=SRO/PHAI
 cc	WRITE(6,340) SRO
-      IF (IFG.NE.0) WRITE(LU,340) SRO
+cx      IF (IFG.NE.0) WRITE(LU,340) SRO
 cc  340 FORMAT(1H ,'SRO=',D17.5)
   340 FORMAT(/1H ,'SRO=',D17.5)
 C
@@ -1691,7 +1710,7 @@ C     IF(RAM.LE.CONSTA) RAM=CONSTA
       RAM=CONSTA
       IRAM=1
 cc	WRITE(6,420) RAM
-      IF (IFG.NE.0) WRITE(LU,420) RAM
+cx      IF (IFG.NE.0) WRITE(LU,420) RAM
   420 FORMAT(1H ,'RAM=CONSTA=',D17.5)
       GO TO 470
 C     IF(RAM.GE.CONSTB) RAM=CONSTB
@@ -1699,14 +1718,14 @@ C     IF(RAM.GE.CONSTB) RAM=CONSTB
       RAM=CONSTB
       IRAM=-1
 cc	WRITE(6,440) RAM
-      IF (IFG.NE.0) WRITE(LU,440) RAM
+cx      IF (IFG.NE.0) WRITE(LU,440) RAM
   440 FORMAT(1H ,'RAM=CONSTB=',D17.5)
       GO TO 470
 C     RAM=RAM
   450 CONTINUE
       IRAM=0
 cc	WRITE(6,460) RAM
-      IF (IFG.NE.0) WRITE(LU,460) RAM
+cx      IF (IFG.NE.0) WRITE(LU,460) RAM
   460 FORMAT(1H ,'RAM=DGAM/(DGAM+1.0)=',D17.5)
 C
 C     V=V+((RAM-1.0)/SRO)*(SR)*(SR)'
@@ -1750,7 +1769,7 @@ C     SPHAI.LT.PHAI: SUCCESSFUL REDUCTION
 cc	WRITE(6,810) OPHAI,SPHAI,AICO,AICS,DAIC
 cc  810 FORMAT(1H ,'OPHAI=',D17.5,5X,'SPHAI=',D17.5,5X,'OAIC=',D17.5,5X,'A
 cc     AIC=',D17.5,5X,'DAIC=',D17.5)
-      IF (IFG.NE.0) WRITE(LU,810) OPHAI,SPHAI,AICO,AICS,DAIC
+cx      IF (IFG.NE.0) WRITE(LU,810) OPHAI,SPHAI,AICO,AICS,DAIC
   810 FORMAT(1H ,'OPHAI=',D17.5,5X,'SPHAI=',D17.5,/,' OAIC=',D17.5,5X,'A
      AIC=',D17.5,5X,'DAIC=',D17.5)
       IF(IRAM.NE.0) GO TO 901
@@ -1771,17 +1790,17 @@ C
  1000 CONTINUE
       AICD=AN*DLOG(PHAID)+CST2*AIPQ
 cc	WRITE(6,3609) AICD
-      IF (IFG.NE.0) WRITE(LU,3609) AICD
+cx      IF (IFG.NE.0) WRITE(LU,3609) AICD
  3609 FORMAT(/1H ,'AIC=N*LOG(DET(CXX0))+2.0*IPQ=',D12.5)
 C     INNOVATION VARIANCE PRINT OUT
 cc	WRITE(6,3610)
 cc	DO 3620 I=1,ID
 cc 3620 WRITE(6,3630) I,(C0(I,J),J=1,ID)
-      IF (IFG.NE.0) THEN
-	 WRITE(LU,3610)
-	 DO 3620 I=1,ID
- 3620	 WRITE(LU,3630) I,(C0(I,J),J=1,ID)
-      END IF
+cx      IF (IFG.NE.0) THEN
+cx	 WRITE(LU,3610)
+cx	 DO 3620 I=1,ID
+cx 3620	 WRITE(LU,3630) I,(C0(I,J),J=1,ID)
+cx      END IF
       RETURN
  3610 FORMAT(/1H ,'INNOVATION VARIANCE')
  3630 FORMAT(/1H ,I5,10D12.5,/(1H ,5X,10D12.5))
@@ -1973,7 +1992,8 @@ cc  504 CONTINUE
       END
 C
 cc	SUBROUTINE  RESCAL ( K,ID )
-      SUBROUTINE  RESCAL ( B,AW,IAW,NH,IDD,IR,IJ,IDUMMY,K,ID,IFG,LU )
+cx      SUBROUTINE  RESCAL ( B,AW,IAW,NH,IDD,IR,IJ,IDUMMY,K,ID,IFG,LU )
+      SUBROUTINE  RESCAL ( B,AW,IAW,NH,IDD,IR,IJ,IDUMMY,K,ID )
 C     RESCALING OF F AND G MATRICES FOR A FEASIBLE INITIAL
       IMPLICIT REAL*8(A-H,O-Z)
 cc	COMMON /COM60/IDD , IR
@@ -1988,7 +2008,7 @@ cc	DIMENSION IDD(10)
 cc	DIMENSION IO(10)
       DIMENSION AW(IAW),B(K,ID)
       DIMENSION IJ(ID),NH(K),IR(K)
-      DIMENSION IDUMMY(ID)
+cc      DIMENSION IDUMMY(ID)
       DIMENSION IDD(K)
       DIMENSION IO(K)
 C
@@ -2019,7 +2039,7 @@ C     G MATRIX RESCALING
    50 B(I,J) = B(I,J) * SCALE
    40 CONTINUE
 cc	WRITE(6,2000)
-      IF (IFG.NE.0) WRITE(LU,2000)
+cx      IF (IFG.NE.0) WRITE(LU,2000)
  2000 FORMAT(/1H ,'INITIAL MODIFIED FOR FEASIBILITY')
       RETURN
       END
@@ -2067,37 +2087,3 @@ cc	DIMENSION X(MJ,MJ)
    17 RETURN
       END
 C
-cc	SUBROUTINE SUBVCP(HH,LC)
-      SUBROUTINE SUBVCP(HH,LC,LU)
-C *** COMMON SUBROUTINE
-C     THIS SUBROUTINE PRINTS OUT VECTOR (HH(I),I=1,LC).
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION HH(LC)
-cc	WRITE(6,39) LC
-cc     WRITE(6,20)
-      WRITE(LU,39) LC
-cc	WRITE(LU,20)
-      J1=0
-      J2=0
-cc	I=1
-      JC=0
-   16 J1=J2+1
-cc	J2=J1+9
-      J2=J1+4
-      IF(J2.LE.LC) GO TO 13
-   12 J2=LC
-   13 JC=JC+1
-cc	WRITE(6,21) I,(HH(J),J=J1,J2)
-      WRITE(LU,20) (J,J=J1,J2)
-      WRITE(LU,21) (HH(J),J=J1,J2)
-   17 IF(J2.GE.LC) GO TO 10
-cc   14 I=I+10
-      GO TO 16
-   10 RETURN
-   39 FORMAT(/1H ,6HVECTOR,5X,3HLC=,I5)
-cc   20 FORMAT(/1H ,15X,1H1,11X,1H2,11X,1H3,11X,1H4,11X,1H5,11X,1H6,11X,1
-cc     AH7,11X,1H8,11X,1H9,10X,2H10)
-cc   21 FORMAT(1H ,I5,4X,10D12.5)
-   20 FORMAT(/5(5X,I2,9X))
-   21 FORMAT(10(D12.5,4X))
-      END
