@@ -1,5 +1,6 @@
       SUBROUTINE NONSTF(N,ISTP,DATA0,NM,LAGH,JP0,COEF0,VA0,AIC0,DAIC21,
-     *		          DAIC,K01,KOUNT2,SXX,TMP)
+cx     *		          DAIC,K01,KOUNT2,SXX,TMP,IER)
+     *		          DAIC,K01,KOUNT2,SXX)
 C
       INCLUDE 'timsac_f.h'
 C
@@ -50,35 +51,37 @@ cc	REAL*4 SXX(121)
       DIMENSION VA0(NM),AIC0(NM),DAIC21(NM),DAIC(NM)
       DIMENSION K01(NM),KOUNT2(NM)
 C
-      INTEGER*1  TMP(1)
-      CHARACTER  CNAME*80
+cx      INTEGER*1  TMP(1)
+cx      CHARACTER  CNAME*80
 C
 C     INPUT / OUTPUT DATA FILE OPEN
 cc	CALL SETWND
 cc	CALL FLOPN2(NFL)
 cc	IF (NFL.EQ.0) GO TO 9999
 C
-      LU=3
-      DO 10 I = 1,80
-   10 CNAME(I:I) = ' '
-      I = 1
-      IFG = 1
-      DO WHILE( (IFG.EQ.1) .AND. (I.LE.80) )
-	   IF ( TMP(I).NE.ICHAR(' ') ) THEN
-            CNAME(I:I) = CHAR(TMP(I))
-            I = I+1
-         ELSE
-            IFG = 0
-         END IF
-      END DO
-      IF ( I.GT.1 ) THEN
-         IFG = 1
-         OPEN (LU,FILE=CNAME,IOSTAT=IVAR)
-         IF (IVAR .NE. 0) THEN
-            WRITE(*,*) ' ***  nonst temp FILE OPEN ERROR :',CNAME,IVAR
-            IFG=0
-         END IF
-      END IF
+cx      IER=0
+cx      LU=3
+cx      DO 10 I = 1,80
+cx   10 CNAME(I:I) = ' '
+cx      I = 1
+cx      IFG = 1
+cx      DO WHILE( (IFG.EQ.1) .AND. (I.LE.80) )
+cx	   IF ( TMP(I).NE.ICHAR(' ') ) THEN
+cx            CNAME(I:I) = CHAR(TMP(I))
+cx            I = I+1
+cx         ELSE
+cx            IFG = 0
+cx         END IF
+cx      END DO
+cx      IF ( I.GT.1 ) THEN
+cx         IFG = 1
+cx         OPEN (LU,FILE=CNAME,IOSTAT=IVAR)
+cx         IF (IVAR .NE. 0) THEN
+cxcx            WRITE(*,*) ' ***  nonst temp FILE OPEN ERROR :',CNAME,IVAR
+cx            IER=IVAR
+cx            IFG=0
+cx         END IF
+cx      END IF
 C
 C     INITIALIZATION
 cc	LAGH=50
@@ -119,8 +122,8 @@ cc	WRITE(6,8001) NI
 cc	WRITE(6,8002) IP0
 cc	WRITE(6,8003)
       JP0(1)=IP0
-      IF (IFG.NE.0) WRITE(LU,8001) NI
-      IF (IFG.NE.0) WRITE(LU,8002) JP0(1)
+cx      IF (IFG.NE.0) WRITE(LU,8001) NI
+cx      IF (IFG.NE.0) WRITE(LU,8002) JP0(1)
       IDX(1)=1
       DO 60 I=1,4
       J=I+1
@@ -141,13 +144,13 @@ cc	WRITE(6,8008) AIC0
 cc	K01=KOUNT0+1
       K01(1)=KOUNT0+1
 cc	WRITE(6,8009) K01,KOUNT2
-      IF (IFG.NE.0) WRITE(LU,8009) K01(1),KOUNT2(1)
+cx      IF (IFG.NE.0) WRITE(LU,8009) K01(1),KOUNT2(1)
 C     COMON  SUBROUTINE	 CALL
 cc	CALL NRASPE(VA0,COEF0,Z,SXX,IP0,0,ISTP,120,KOUNT0,KOUNT2)
 cc	CALL SPEGRH(SXX)
       NSG1=NSG-1
       CALL NRASPE(VA0(1),COEF0(1,1),Z,IP0,0,NSG1,SXX)
-      IF (IFG.NE.0) CALL SPEGRH(LU,SXX,NSG)
+cx      IF (IFG.NE.0) CALL SPEGRH(LU,SXX,NSG)
       NML=1
 100	J=NI+1
       JJ=J+ISTP
@@ -202,8 +205,8 @@ cc	WRITE(6,8001) NI
 cc	WRITE(6,8002) IP0
 cc	WRITE(6,8003)
       JP0(NML)=IP0
-      IF (IFG.NE.0) WRITE(LU,8001) NI
-      IF (IFG.NE.0) WRITE(LU,8001) JP0(NML)
+cx      IF (IFG.NE.0) WRITE(LU,8001) NI
+cx      IF (IFG.NE.0) WRITE(LU,8001) JP0(NML)
       IDX(1)=1
       DO 760 I=1,4
       J=I+1
@@ -234,7 +237,7 @@ C     COMON  SUBROUTINE	 CALL
 cc	CALL NRASPE(VA0,COEF0,Z,SXX,IP0,0,NI,120,KOUNT0,KOUNT2)
 cc	CALL SPEGRH(SXX)
       CALL NRASPE(VA0(NML),COEF0(1,NML),Z,IP0,0,NSG1,SXX(1,NML))
-      IF (IFG.NE.0) CALL SPEGRH(LU,SXX(1,NML),NSG)
+cx      IF (IFG.NE.0) CALL SPEGRH(LU,SXX(1,NML),NSG)
       GOTO 100
 800	NI=ISTP
       IP0=IP2
@@ -253,8 +256,8 @@ cc	WRITE(6,8001) NI
 cc	WRITE(6,8002) IP0
 cc	WRITE(6,8003)
       JP0(NML)=IP0
-      IF (IFG.NE.0) WRITE(LU,8001) NI
-      IF (IFG.NE.0) WRITE(LU,8002) JP0(NML)
+cx      IF (IFG.NE.0) WRITE(LU,8001) NI
+cx      IF (IFG.NE.0) WRITE(LU,8002) JP0(NML)
       IDX(1)=1
       DO 1060 I=1,4
       J=I+1
@@ -286,10 +289,10 @@ C     COMON  SUBROUTINE	 CALL
 cc	CALL NRASPE(VA0,COEF0,Z,SXX,IP0,0,NI,120,KOUNT0,KOUNT2)
 cc	CALL SPEGRH(SXX)
       CALL NRASPE(VA0(NML),COEF0(1,NML),Z,IP0,0,NSG1,SXX(1,NML))
-      IF (IFG.NE.0) CALL SPEGRH(LU,SXX(1,NML),NSG)
+cx      IF (IFG.NE.0) CALL SPEGRH(LU,SXX(1,NML),NSG)
       GOTO 100
 999   CONTINUE
-      IF (IFG.NE.0) CLOSE(LU)
+cx      IF (IFG.NE.0) CLOSE(LU)
 cc	CALL FLCLS2(NFL)
 cc9999	CONTINUE
 cc	STOP
@@ -312,105 +315,6 @@ cc	STOP
       RETURN
       END
 C
-cc	SUBROUTINE SPEGRH(SXX)
-      SUBROUTINE SPEGRH(LU,SXX0,NSG)
-C     THIS SUBROUTINE GRAPHICALLY PRINTS OUT SPECTRA BY LINE PRINTER.
-C     SXX(I)S ARE THE VALUES OF THE POWER SPECTRUM DENSITY AT THE RELATI
-C     FREQUENCIES (I-1)/240 (I=1,2,...,121).
-cc      REAL*8 SXX,CMAX,CMIN
-cc	DIMENSION SXX(121),TT(66,132)
-cc	INTEGER IXX(121)
-      REAL*8 SXX0,SXX,CMAX,CMIN
-      DIMENSION SXX0(NSG),SXX(NSG),TT(66,NSG)
-      INTEGER IXX(NSG)
-      CHARACTER(4) S0, S1, S2, S3, S4, S5
-      CHARACTER(4) TT
-      DATA S0/'    '/,S1/'X   '/,S2/'*   '/,S3/'-   '/,S4/'I   '/
-      DATA S5/'+   '/
-      CMAX=-1000.
-      CMIN=10000.
-cc	DO 120 I=1,121
-      DO 120 I=1,NSG
-      SXX(I)=SXX0(I)*10.
-      IF(CMAX.GT.SXX(I)) GO TO 110
-      CMAX=SXX(I)
-110   IF(CMIN.LT.SXX(I)) GO TO 120
-      CMIN=SXX(I)
-120   CONTINUE
-      MAX=(INT(CMAX/10.)+1)*10
-      MIN=MAX-60
-cc	DO 290 I=1,121
-      DO 290 I=1,NSG
-      IF(MAX.LT.60) GO TO 210
-      MAX=60
-      MIN=0
-210   IXX(I)=SXX(I)+60-MAX
-      A1=(SXX(I)+60-MAX)*10.-IXX(I)*10
-      IF(A1.GE.5) GO TO 230
-      IF(A1.LE.-5) GO TO 240
-      GO TO 290
-230   IXX(I)=IXX(I)+1
-      GO TO 290
-240   IXX(I)=IXX(I)-1
-290   CONTINUE
-      DO 310 I=1,66
-cc	DO 300 J=1,132
-      DO 300 J=1,NSG
-300   TT(I,J)=S0
-310   CONTINUE
-      DO 320 I=3,62
-320   TT(I,1)=S4
-cc	DO 330 J=1,121
-      DO 330 J=1,NSG
-330   TT(63,J)=S3
-cc	DO 490 J=1,121
-      DO 490 J=1,NSG
-      K=60-IXX(J)+3
-      IF(K.GE.3) GO TO 410
-      TT(3,J)=S2
-      GO TO 490
-410   IF(K.LE.62) GO TO 420
-      TT(62,J)=S2
-      GO TO 490
-420   TT(K,J)=S1
-490   CONTINUE
-      CMAX=MAX
-      TT(3,1)=S5
-cc	WRITE(6,899)
-cc	WRITE(6,900) CMAX,(TT(3,J),J=1,121)
-      WRITE(LU,899)
-      WRITE(LU,900) CMAX,(TT(3,J),J=1,NSG)
-      DO 810 J=1,6
-      J1=(J-1)*24+1
-810   TT(63,J1)=S5
-      A1=CMAX
-      IK=3
-      DO 890 I=1,6
-      DO 880 K=1,9
-      IK=IK+1
-cc880	WRITE(6,901) (TT(IK,J),J=1,121)
-880   WRITE(LU,901) (TT(IK,J),J=1,NSG)
-      A1=A1-10.
-      IK=IK+1
-      TT(IK,1)=S5
-cc	WRITE(6,902) A1,(TT(IK,J),J=1,121)
-      WRITE(LU,902) A1,(TT(IK,J),J=1,NSG)
-890   CONTINUE
-cc	WRITE(6,903)
-cc	WRITE(6,904)
-      WRITE(LU,903)
-      WRITE(LU,904)
-      RETURN
-899   FORMAT(//1H ,40X,'POWER   SPECTRAL   DENSITY   IN   DB')
-900   FORMAT(1H ,/,1H ,3X,F5.1,121A1)
-901   FORMAT(1H ,8X,121A1)
-902   FORMAT(1H ,3X,F5.1,121A1)
-903   FORMAT(1H ,7X,'0.0',21X,'0.1',21X,'0.2',21X,'0.3',21X,'0.4',21X,
-     C'0.5')
-904   FORMAT(1H ,60X,'FREQUENCY',/)
-905   FORMAT(1H ,10I5)
-906   FORMAT(1H ,10F10.2)
-      END
 C
       SUBROUTINE SICP(CXX,COEF,OSD,L1,N,MO)
 C     THIS SUBROUTINE FITS AUTOREGRESSIVE MODELS
